<a id="mypy-boto3-xray"></a>

# mypy-boto3-xray

[![PyPI - mypy-boto3-xray](https://img.shields.io/pypi/v/mypy-boto3-xray.svg?color=blue)](https://pypi.org/project/mypy-boto3-xray)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-xray.svg?color=blue)](https://pypi.org/project/mypy-boto3-xray)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-xray?color=blue)](https://pypistats.org/packages/mypy-boto3-xray)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.XRay 1.18.53](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/xray.html#XRay)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-xray docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_xray/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-xray](#mypy-boto3-xray)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `XRay` service.

```bash
python -m pip install boto3-stubs[xray]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[xray]` in your environment:
  `python -m pip install 'boto3-stubs[xray]'`

Both type checking and auto-complete should work for `XRay` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[xray]` in your environment:
  `python -m pip install 'boto3-stubs[xray]'`

Both type checking and auto-complete should work for `XRay` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[xray]` in your environment:
  `python -m pip install 'boto3-stubs[xray]'`
- Run `mypy` as usual

Type checking should work for `XRay` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[xray]` in your environment:
  `python -m pip install 'boto3-stubs[xray]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `XRay` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`XRayClient` provides annotations for `boto3.client("xray")`.

```python
import boto3

from mypy_boto3_xray import XRayClient

client: XRayClient = boto3.client("xray")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: XRayClient = session.client("xray")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_xray.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_xray import XRayClient
from mypy_boto3_xray.paginator import (
    BatchGetTracesPaginator,
    GetGroupsPaginator,
    GetSamplingRulesPaginator,
    GetSamplingStatisticSummariesPaginator,
    GetServiceGraphPaginator,
    GetTimeSeriesServiceStatisticsPaginator,
    GetTraceGraphPaginator,
    GetTraceSummariesPaginator,
)

client: XRayClient = boto3.client("xray")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
batch_get_traces_paginator: BatchGetTracesPaginator = client.get_paginator("batch_get_traces")
get_groups_paginator: GetGroupsPaginator = client.get_paginator("get_groups")
get_sampling_rules_paginator: GetSamplingRulesPaginator = client.get_paginator("get_sampling_rules")
get_sampling_statistic_summaries_paginator: GetSamplingStatisticSummariesPaginator = client.get_paginator("get_sampling_statistic_summaries")
get_service_graph_paginator: GetServiceGraphPaginator = client.get_paginator("get_service_graph")
get_time_series_service_statistics_paginator: GetTimeSeriesServiceStatisticsPaginator = client.get_paginator("get_time_series_service_statistics")
get_trace_graph_paginator: GetTraceGraphPaginator = client.get_paginator("get_trace_graph")
get_trace_summaries_paginator: GetTraceSummariesPaginator = client.get_paginator("get_trace_summaries")
```

<a id="literals"></a>

### Literals

`mypy_boto3_xray.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_xray.literals import (
    BatchGetTracesPaginatorName,
    EncryptionStatusType,
    EncryptionTypeType,
    GetGroupsPaginatorName,
    GetSamplingRulesPaginatorName,
    GetSamplingStatisticSummariesPaginatorName,
    GetServiceGraphPaginatorName,
    GetTimeSeriesServiceStatisticsPaginatorName,
    GetTraceGraphPaginatorName,
    GetTraceSummariesPaginatorName,
    InsightCategoryType,
    InsightStateType,
    SamplingStrategyNameType,
    TimeRangeTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: BatchGetTracesPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_xray.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_xray.type_defs import (
    AliasTypeDef,
    AnnotationValueTypeDef,
    AnomalousServiceTypeDef,
    AvailabilityZoneDetailTypeDef,
    BackendConnectionErrorsTypeDef,
    BatchGetTracesRequestRequestTypeDef,
    BatchGetTracesResultTypeDef,
    CreateGroupRequestRequestTypeDef,
    CreateGroupResultTypeDef,
    CreateSamplingRuleRequestRequestTypeDef,
    CreateSamplingRuleResultTypeDef,
    DeleteGroupRequestRequestTypeDef,
    DeleteSamplingRuleRequestRequestTypeDef,
    DeleteSamplingRuleResultTypeDef,
    EdgeStatisticsTypeDef,
    EdgeTypeDef,
    EncryptionConfigTypeDef,
    ErrorRootCauseEntityTypeDef,
    ErrorRootCauseServiceTypeDef,
    ErrorRootCauseTypeDef,
    ErrorStatisticsTypeDef,
    FaultRootCauseEntityTypeDef,
    FaultRootCauseServiceTypeDef,
    FaultRootCauseTypeDef,
    FaultStatisticsTypeDef,
    ForecastStatisticsTypeDef,
    GetEncryptionConfigResultTypeDef,
    GetGroupRequestRequestTypeDef,
    GetGroupResultTypeDef,
    GetGroupsRequestRequestTypeDef,
    GetGroupsResultTypeDef,
    GetInsightEventsRequestRequestTypeDef,
    GetInsightEventsResultTypeDef,
    GetInsightImpactGraphRequestRequestTypeDef,
    GetInsightImpactGraphResultTypeDef,
    GetInsightRequestRequestTypeDef,
    GetInsightResultTypeDef,
    GetInsightSummariesRequestRequestTypeDef,
    GetInsightSummariesResultTypeDef,
    GetSamplingRulesRequestRequestTypeDef,
    GetSamplingRulesResultTypeDef,
    GetSamplingStatisticSummariesRequestRequestTypeDef,
    GetSamplingStatisticSummariesResultTypeDef,
    GetSamplingTargetsRequestRequestTypeDef,
    GetSamplingTargetsResultTypeDef,
    GetServiceGraphRequestRequestTypeDef,
    GetServiceGraphResultTypeDef,
    GetTimeSeriesServiceStatisticsRequestRequestTypeDef,
    GetTimeSeriesServiceStatisticsResultTypeDef,
    GetTraceGraphRequestRequestTypeDef,
    GetTraceGraphResultTypeDef,
    GetTraceSummariesRequestRequestTypeDef,
    GetTraceSummariesResultTypeDef,
    GroupSummaryTypeDef,
    GroupTypeDef,
    HistogramEntryTypeDef,
    HttpTypeDef,
    InsightEventTypeDef,
    InsightImpactGraphEdgeTypeDef,
    InsightImpactGraphServiceTypeDef,
    InsightSummaryTypeDef,
    InsightTypeDef,
    InsightsConfigurationTypeDef,
    InstanceIdDetailTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutEncryptionConfigRequestRequestTypeDef,
    PutEncryptionConfigResultTypeDef,
    PutTelemetryRecordsRequestRequestTypeDef,
    PutTraceSegmentsRequestRequestTypeDef,
    PutTraceSegmentsResultTypeDef,
    RequestImpactStatisticsTypeDef,
    ResourceARNDetailTypeDef,
    ResponseMetadataTypeDef,
    ResponseTimeRootCauseEntityTypeDef,
    ResponseTimeRootCauseServiceTypeDef,
    ResponseTimeRootCauseTypeDef,
    RootCauseExceptionTypeDef,
    SamplingRuleRecordTypeDef,
    SamplingRuleTypeDef,
    SamplingRuleUpdateTypeDef,
    SamplingStatisticSummaryTypeDef,
    SamplingStatisticsDocumentTypeDef,
    SamplingStrategyTypeDef,
    SamplingTargetDocumentTypeDef,
    SegmentTypeDef,
    ServiceIdTypeDef,
    ServiceStatisticsTypeDef,
    ServiceTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TelemetryRecordTypeDef,
    TimeSeriesServiceStatisticsTypeDef,
    TraceSummaryTypeDef,
    TraceTypeDef,
    TraceUserTypeDef,
    UnprocessedStatisticsTypeDef,
    UnprocessedTraceSegmentTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateGroupRequestRequestTypeDef,
    UpdateGroupResultTypeDef,
    UpdateSamplingRuleRequestRequestTypeDef,
    UpdateSamplingRuleResultTypeDef,
    ValueWithServiceIdsTypeDef,
)

def get_structure() -> AliasTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-xray` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-xray docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_xray/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
